@@ -27,8 +27,10 @@ SOFTWARE.
 
 #include "kernel/non_silent_region_detection.hpp"
 #include "kernel/down_mixing.hpp"
+#include "kernel/mel_filter_bank.hpp"
 #include "kernel/pre_emphasis_filter.hpp"
 #include "kernel/to_decibels.hpp"
 #include "kernel/resample.hpp"
+#include "kernel/spectrogram.hpp"
 
 #endif // HIP_TENSOR_AUDIO_AUGMENTATIONS_HPP
