@@ -30,6 +30,26 @@ __device__ void gaussian_noise_24_hip_compute(d_float24 *pix_f24, RpptXorwowStat
     rpp_hip_pixel_check_0to1(pix_f24);
 }
 
+__device__ void gaussian_noise_voxel_8_hip_compute(d_float8 *pix_f8, RpptXorwowStateBoxMuller *xorwowState, float mean, float stdDev)
+{
+    d_float8 rngVals_f8, pixSqrt_f8;
+    rpp_hip_rng_8_gaussian_f32(&rngVals_f8, xorwowState);
+    rpp_hip_math_multiply8_const(&rngVals_f8, &rngVals_f8, (float4)stdDev);
+    rpp_hip_math_add8_const(&rngVals_f8, &rngVals_f8, (float4)mean);
+    rpp_hip_math_add8(pix_f8, &rngVals_f8, pix_f8);
+}
+
+__device__ void gaussian_noise_voxel_24_hip_compute(d_float24 *pix_f24, RpptXorwowStateBoxMuller *xorwowState, float mean, float stdDev)
+{
+    d_float24 rngVals_f24, pixSqrt_f24;
+    rpp_hip_rng_8_gaussian_f32(&rngVals_f24.f8[0], xorwowState);
+    rpp_hip_rng_8_gaussian_f32(&rngVals_f24.f8[1], xorwowState);
+    rpp_hip_rng_8_gaussian_f32(&rngVals_f24.f8[2], xorwowState);
+    rpp_hip_math_multiply24_const(&rngVals_f24, &rngVals_f24, (float4)stdDev);
+    rpp_hip_math_add24_const(&rngVals_f24, &rngVals_f24, (float4)mean);
+    rpp_hip_math_add24(pix_f24, &rngVals_f24, pix_f24);
+}
+
 __device__ void gaussian_noise_8_adjusted_input_hip_compute(uchar *srcPtr, d_float8 *pix_f8) { rpp_hip_math_multiply8_const(pix_f8, pix_f8, (float4)ONE_OVER_255); }
 __device__ void gaussian_noise_8_adjusted_input_hip_compute(float *srcPtr, d_float8 *pix_f8) { }
 __device__ void gaussian_noise_8_adjusted_input_hip_compute(schar *srcPtr, d_float8 *pix_f8) { rpp_hip_math_add8_const(pix_f8, pix_f8, (float4)128.0f); rpp_hip_math_multiply8_const(pix_f8, pix_f8, (float4)ONE_OVER_255); }
@@ -253,6 +273,92 @@ __global__ void gaussian_noise_pln3_pkd3_hip_tensor(T *srcPtr,
     rpp_hip_pack_float24_pln3_and_store24_pkd3(dstPtr + dstIdx, &pix_f24);
 }
 
+template<typename T>
+__global__ void gaussian_noise_voxel_ncdhw_hip_tensor(T *srcPtr,
+                                                      uint3 srcStridesCDH,
+                                                      T *dstPtr,
+                                                      uint3 dstStridesCDH,
+                                                      int channels,
+                                                      float2 gaussianNoise3dParams_f2,
+                                                      RpptXorwowStateBoxMuller *xorwowInitialStatePtr,
+                                                      uint *xorwowSeedStream,
+                                                      RpptROI3DPtr roiGenericSrc)
+{
+    int id_x = (hipBlockIdx_x * hipBlockDim_x + hipThreadIdx_x) * 8;        // W - inner most dim vectorized
+    int id_y = hipBlockIdx_y * hipBlockDim_y + hipThreadIdx_y;              // H - second to inner
+    int id_z = hipBlockIdx_z * hipBlockDim_z + hipThreadIdx_z;              // D - outer most dim
+
+    if ((id_z >= roiGenericSrc->xyzwhdROI.roiDepth) || (id_y >= roiGenericSrc->xyzwhdROI.roiHeight) || (id_x >= roiGenericSrc->xyzwhdROI.roiWidth))
+    {
+        return;
+    }
+
+    uint srcIdx = ((id_z + roiGenericSrc->xyzwhdROI.xyz.z) * srcStridesCDH.y) + ((id_y + roiGenericSrc->xyzwhdROI.xyz.y) * srcStridesCDH.z) + (id_x + roiGenericSrc->xyzwhdROI.xyz.x);
+    uint dstIdx = (id_z * dstStridesCDH.y) + (id_y * dstStridesCDH.z) + id_x;
+    uint seedStreamIdx = (id_y * dstStridesCDH.z) + (hipBlockIdx_x * hipBlockDim_x) + hipThreadIdx_x;
+
+    RpptXorwowStateBoxMuller xorwowState;
+    uint xorwowSeed = xorwowSeedStream[seedStreamIdx % SEED_STREAM_MAX_SIZE];
+    xorwowState.x[0] = xorwowInitialStatePtr->x[0] + xorwowSeed;
+    xorwowState.x[1] = xorwowInitialStatePtr->x[1] + xorwowSeed;
+    xorwowState.x[2] = xorwowInitialStatePtr->x[2] + xorwowSeed;
+    xorwowState.x[3] = xorwowInitialStatePtr->x[3] + xorwowSeed;
+    xorwowState.x[4] = xorwowInitialStatePtr->x[4] + xorwowSeed;
+    xorwowState.counter = xorwowInitialStatePtr->counter + xorwowSeed;
+
+    d_float8 val_f8;
+    for(int c = 0; c < channels; c++)
+    {
+        rpp_hip_load8_and_unpack_to_float8(srcPtr + srcIdx, &val_f8);
+        gaussian_noise_8_adjusted_input_hip_compute(srcPtr, &val_f8);
+        gaussian_noise_voxel_8_hip_compute(&val_f8, &xorwowState, gaussianNoise3dParams_f2.x, gaussianNoise3dParams_f2.y);
+        gaussian_noise_8_adjusted_output_hip_compute(srcPtr, &val_f8);
+        rpp_hip_pack_float8_and_store8(dstPtr + dstIdx, &val_f8);
+        srcIdx += srcStridesCDH.x;
+        dstIdx += dstStridesCDH.x;
+    }
+}
+
+template<typename T>
+__global__ void gaussian_noise_voxel_ndhwc_hip_tensor(T *srcPtr,
+                                                      uint2 srcStridesDH,
+                                                      T *dstPtr,
+                                                      uint2 dstStridesDH,
+                                                      float2 gaussianNoise3dParams_f2,
+                                                      RpptXorwowStateBoxMuller *xorwowInitialStatePtr,
+                                                      uint *xorwowSeedStream,
+                                                      RpptROI3DPtr roiGenericSrc)
+{
+    int id_x = (hipBlockIdx_x * hipBlockDim_x + hipThreadIdx_x) * 8;        // WC - inner most dim vectorized
+    int id_y = hipBlockIdx_y * hipBlockDim_y + hipThreadIdx_y;              // H - second to inner
+    int id_z = hipBlockIdx_z * hipBlockDim_z + hipThreadIdx_z;              // D - outer most dim
+
+    if ((id_z >= roiGenericSrc->xyzwhdROI.roiDepth) || (id_y >= roiGenericSrc->xyzwhdROI.roiHeight) || (id_x >= roiGenericSrc->xyzwhdROI.roiWidth))
+    {
+        return;
+    }
+
+    uint srcIdx = ((id_z + roiGenericSrc->xyzwhdROI.xyz.z) * srcStridesDH.x) + ((id_y + roiGenericSrc->xyzwhdROI.xyz.y) * srcStridesDH.y) + (id_x + roiGenericSrc->xyzwhdROI.xyz.x) * 3;
+    uint dstIdx = (id_z * dstStridesDH.x) + (id_y * dstStridesDH.y) + id_x * 3;
+    uint seedStreamIdx = (id_y * dstStridesDH.y) + (hipBlockIdx_x * hipBlockDim_x) + hipThreadIdx_x;
+
+    RpptXorwowStateBoxMuller xorwowState;
+    uint xorwowSeed = xorwowSeedStream[seedStreamIdx % SEED_STREAM_MAX_SIZE];
+    xorwowState.x[0] = xorwowInitialStatePtr->x[0] + xorwowSeed;
+    xorwowState.x[1] = xorwowInitialStatePtr->x[1] + xorwowSeed;
+    xorwowState.x[2] = xorwowInitialStatePtr->x[2] + xorwowSeed;
+    xorwowState.x[3] = xorwowInitialStatePtr->x[3] + xorwowSeed;
+    xorwowState.x[4] = xorwowInitialStatePtr->x[4] + xorwowSeed;
+    xorwowState.counter = xorwowInitialStatePtr->counter + xorwowSeed;
+
+    d_float24 val_f24;
+    rpp_hip_load24_pkd3_and_unpack_to_float24_pln3(srcPtr + srcIdx, &val_f24);
+    gaussian_noise_24_adjusted_input_hip_compute(srcPtr, &val_f24);
+    gaussian_noise_voxel_24_hip_compute(&val_f24, &xorwowState, gaussianNoise3dParams_f2.x, gaussianNoise3dParams_f2.y);
+    gaussian_noise_24_adjusted_output_hip_compute(srcPtr, &val_f24);
+    rpp_hip_pack_float24_pln3_and_store24_pkd3(dstPtr + dstIdx, &val_f24);
+}
+
 template <typename T>
 RppStatus hip_exec_gaussian_noise_tensor(T *srcPtr,
                                          RpptDescPtr srcDescPtr,
@@ -351,3 +457,106 @@ RppStatus hip_exec_gaussian_noise_tensor(T *srcPtr,
 
     return RPP_SUCCESS;
 }
+
+template <typename T>
+RppStatus hip_exec_gaussian_noise_voxel_tensor(T *srcPtr,
+                                               RpptGenericDescPtr srcGenericDescPtr,
+                                               T *dstPtr,
+                                               RpptGenericDescPtr dstGenericDescPtr,
+                                               RpptXorwowStateBoxMuller *xorwowInitialStatePtr,
+                                               Rpp32f *meanTensor,
+                                               Rpp32f *stdDevTensor,
+                                               RpptROI3DPtr roiGenericPtrSrc,
+                                               rpp::Handle& handle)
+{
+    Rpp32u *xorwowSeedStream;
+    xorwowSeedStream = (Rpp32u *)&xorwowInitialStatePtr[1];
+    CHECK_RETURN_STATUS(hipMemcpy(xorwowSeedStream, rngSeedStream4050, SEED_STREAM_MAX_SIZE * sizeof(Rpp32u), hipMemcpyHostToDevice));
+
+    if (dstGenericDescPtr->layout == RpptLayout::NCDHW)
+    {
+        int globalThreads_x = (dstGenericDescPtr->strides[3] + 7) >> 3; // W - width (x direction) - vectorized for 8 element loads/stores per channel
+        int globalThreads_y = dstGenericDescPtr->dims[3];               // H - height (y direction)
+        int globalThreads_z = dstGenericDescPtr->dims[2];               // D - depth (z direction)
+
+        for(int batchCount = 0; batchCount < dstGenericDescPtr->dims[0]; batchCount++)
+        {
+            bool copyInput = (!meanTensor[batchCount]) && (!stdDevTensor[batchCount]);
+            // copy ROI from input to output when mean = 0 and stdDev = 0
+            if (copyInput)
+            {
+                hipLaunchKernelGGL(copy_ncdhw_hip_tensor,
+                                   dim3(ceil((float)globalThreads_x/LOCAL_THREADS_X), ceil((float)globalThreads_y/LOCAL_THREADS_Y), ceil((float)globalThreads_z/LOCAL_THREADS_Z)),
+                                   dim3(LOCAL_THREADS_X, LOCAL_THREADS_Y, LOCAL_THREADS_Z),
+                                   0,
+                                   handle.GetStream(),
+                                   srcPtr + (batchCount * srcGenericDescPtr->strides[0]),
+                                   make_uint3(srcGenericDescPtr->strides[1], srcGenericDescPtr->strides[2], srcGenericDescPtr->strides[3]),
+                                   dstPtr + (batchCount * dstGenericDescPtr->strides[0]),
+                                   make_uint3(dstGenericDescPtr->strides[1], dstGenericDescPtr->strides[2], dstGenericDescPtr->strides[3]),
+                                   dstGenericDescPtr->dims[1],
+                                   &roiGenericPtrSrc[batchCount]);
+            }
+            else
+            {
+                hipLaunchKernelGGL(gaussian_noise_voxel_ncdhw_hip_tensor,
+                                   dim3(ceil((float)globalThreads_x/LOCAL_THREADS_X), ceil((float)globalThreads_y/LOCAL_THREADS_Y), ceil((float)globalThreads_z/LOCAL_THREADS_Z)),
+                                   dim3(LOCAL_THREADS_X, LOCAL_THREADS_Y, LOCAL_THREADS_Z),
+                                   0,
+                                   handle.GetStream(),
+                                   srcPtr + (batchCount * srcGenericDescPtr->strides[0]),
+                                   make_uint3(srcGenericDescPtr->strides[1], srcGenericDescPtr->strides[2], srcGenericDescPtr->strides[3]),
+                                   dstPtr + (batchCount * dstGenericDescPtr->strides[0]),
+                                   make_uint3(dstGenericDescPtr->strides[1], dstGenericDescPtr->strides[2], dstGenericDescPtr->strides[3]),
+                                   dstGenericDescPtr->dims[1],
+                                   make_float2(meanTensor[batchCount], stdDevTensor[batchCount]),
+                                   xorwowInitialStatePtr,
+                                   xorwowSeedStream,
+                                   &roiGenericPtrSrc[batchCount]);
+            }
+        }
+    }
+    else if (dstGenericDescPtr->layout == RpptLayout::NDHWC)
+    {
+        int globalThreads_x = (dstGenericDescPtr->strides[2] / 3 + 7) >> 3; // W - width (x direction) - vectorized for 8 element loads/stores per channel
+        int globalThreads_y = dstGenericDescPtr->dims[2];               // H - height (y direction)
+        int globalThreads_z = dstGenericDescPtr->dims[1];               // D - depth (z direction)
+
+        for(int batchCount = 0; batchCount < dstGenericDescPtr->dims[0]; batchCount++)
+        {
+            bool copyInput = (!meanTensor[batchCount]) && (!stdDevTensor[batchCount]);
+            // copy ROI from input to output when mean = 0 and stdDev = 0
+            if (copyInput)
+            {
+                hipLaunchKernelGGL(copy_ndhwc_hip_tensor,
+                                   dim3(ceil((float)globalThreads_x/LOCAL_THREADS_X), ceil((float)globalThreads_y/LOCAL_THREADS_Y), ceil((float)globalThreads_z/LOCAL_THREADS_Z)),
+                                   dim3(LOCAL_THREADS_X, LOCAL_THREADS_Y, LOCAL_THREADS_Z),
+                                   0,
+                                   handle.GetStream(),
+                                   srcPtr + (batchCount * srcGenericDescPtr->strides[0]),
+                                   make_uint2(srcGenericDescPtr->strides[1], srcGenericDescPtr->strides[2]),
+                                   dstPtr + (batchCount * dstGenericDescPtr->strides[0]),
+                                   make_uint2(dstGenericDescPtr->strides[1], dstGenericDescPtr->strides[2]),
+                                   &roiGenericPtrSrc[batchCount]);
+            }
+            else
+            {
+                hipLaunchKernelGGL(gaussian_noise_voxel_ndhwc_hip_tensor,
+                                   dim3(ceil((float)globalThreads_x/LOCAL_THREADS_X), ceil((float)globalThreads_y/LOCAL_THREADS_Y), ceil((float)globalThreads_z/LOCAL_THREADS_Z)),
+                                   dim3(LOCAL_THREADS_X, LOCAL_THREADS_Y, LOCAL_THREADS_Z),
+                                   0,
+                                   handle.GetStream(),
+                                   srcPtr + (batchCount * srcGenericDescPtr->strides[0]),
+                                   make_uint2(srcGenericDescPtr->strides[1], srcGenericDescPtr->strides[2]),
+                                   dstPtr + (batchCount * dstGenericDescPtr->strides[0]),
+                                   make_uint2(dstGenericDescPtr->strides[1], dstGenericDescPtr->strides[2]),
+                                   make_float2(meanTensor[batchCount], stdDevTensor[batchCount]),
+                                   xorwowInitialStatePtr,
+                                   xorwowSeedStream,
+                                   &roiGenericPtrSrc[batchCount]);
+            }
+        }
+    }
+
+    return RPP_SUCCESS;
+}
