@@ -1,9 +1,6 @@
 #include <hip/hip_runtime.h>
-#include <half/half.hpp>
 #include "rpp_hip_host_decls.hpp"
 
-using half_float::half;
-
 #define saturate_8u(value) ((value) > 255 ? 255 : ((value) < 0 ? 0 : (value)))
 
 extern "C" __global__ void resize_pln(unsigned char *srcPtr,
