@@ -313,7 +313,7 @@ int main(int argc, char **argv)
     if (kernelSizeCase)
     {
         char additionalParam_char[2];
-        std::sprintf(additionalParam_char, "%u", additionalParam);
+        std::snprintf(additionalParam_char, sizeof(additionalParam_char), "%u", additionalParam);
         strcat(func, "_kSize");
         strcat(func, additionalParam_char);
         strcat(dst, "_kSize");
